@@ -40,10 +40,22 @@
            <span class="inputhint"><?php echo sprintf(translate("%s chars max"), "16") ?></span>
            <br>
           <label for="personid"><?php echo translate("person") ?></label>
-          <?php echo create_smart_pulldown("person_id", $action == "insert" ? "1" : $this_user->get("person_id"), get_people_select_array()) ?><br>
+          <?php echo create_pulldown("person_id", $action == "insert" ? "1" : $this_user->get("person_id"), get_people_select_array()) ?><br>
+<?php 
+    if($_action=="new") { 
+?>
           <label for="password"><?php echo translate("password") ?></label>
           <input type="password" name="password" id="password" value="" size="16" maxlength="32">
           <span class="inputhint"><?php echo sprintf(translate("%s chars max"), "32") ?></span><br>
+<?php
+    } else {
+?>
+        <span class="actionlink"><a href="password.php?userid=<?php echo $this_user->get("user_id")?>"> 
+            <?php echo translate("change password")?>
+        </a></span>
+<?php
+    }
+?>
           <label for="userclass"><?php echo translate("class") ?></label>
           <?php echo create_pulldown("user_class", $this_user->get("user_class"), array("1" => translate("User",0), "0" => translate("Admin",0)) ) ?>
           <br>
@@ -67,12 +79,18 @@
           <label for="leave_comments"><?php echo translate("can leave comments") ?></label>
           <?php echo create_pulldown("leave_comments", $this_user->get("leave_comments"), array("0" => translate("No",0), "1" => translate("Yes",0)) ) ?>
           <br>
+          <label for="allow_rating"><?php echo translate("can rate photos") ?></label>
+          <?php echo create_pulldown("allow_rating", $this_user->get("allow_rating"), array("0" => translate("No",0), "1" => translate("Yes",0)) ) ?>
+          <br>
+          <label for="allow_multirating"><?php echo translate("can rate the same photo multiple times") ?></label>
+          <?php echo create_pulldown("allow_multirating", $this_user->get("allow_multirating"), array("0" => translate("No",0), "1" => translate("Yes",0)) ) ?>
+          <br>
           <label for="lightboxid"><?php echo translate("lightbox album") ?></label>
 <?php
     $lightbox_array = get_albums_select_array();
     $lightbox_array["null"] = "[none]";
 ?>
-<?php echo create_smart_pulldown("lightbox_id", $this_user->get("lightbox_id"), $lightbox_array) ?>
+<?php echo create_pulldown("lightbox_id", $this_user->get("lightbox_id"), $lightbox_array) ?>
         <br>
             <input type="submit" value="<?php echo translate($action, 0) ?>">
 </form>
