@@ -32,11 +32,13 @@
     require_once("place.inc.php");
     require_once("person.inc.php");
 
-    require_once("album_permissions.inc.php");
+    require_once("group_permissions.inc.php");
     require_once("color_scheme.inc.php");
     require_once("prefs.inc.php");
     require_once("user.inc.php");
+    require_once("group.inc.php");
 
+    require_once("database.inc.php");
     require_once("auth.inc.php");
 
     require_once("album.inc.php");
@@ -49,6 +51,7 @@
 
     require_once("timezone.inc.php");
     require_once("photo.inc.php");
+    require_once("saved_search.inc.php");
     require_once("photo_search.inc.php");
 
 ?>
