@@ -51,23 +51,19 @@ class person extends zoph_table {
         if (!is_numeric($id)) { die("person_id is not numeric"); }
         $sql="update " . DB_PREFIX . "people set father_id=null " .
             "where father_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
 
         $sql="update " . DB_PREFIX . "people set mother_id=null " . 
             "where mother_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
         
         $sql="update " . DB_PREFIX . "people set spouse_id=null " .
             "where spouse_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
         
         $sql="update " . DB_PREFIX . "photos set photographer_id=null where " .
             "photographer_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
         
         parent::delete(null, array("photo_people"));
     }
@@ -150,26 +146,32 @@ class person extends zoph_table {
         return "person";
     }
 
-        function get_coverphoto($user,$autothumb=null) {
+    function get_coverphoto($user,$autothumb=null) {
         if ($this->get("coverphoto")) {
             $coverphoto=new photo($this->get("coverphoto"));
-        } else if ($autothumb) {
+            if(!$coverphoto->lookup($user)) {
+                unset($coverphoto);
+            }
+        } 
+        if ($autothumb && !$coverphoto) {
             $order=get_autothumb_order($autothumb);
             if ($user && !$user->is_admin()) {
                 $sql=
                     "select distinct p.photo_id from " .
-                    DB_PREFIX . "photos as p JOIN " .
-                    DB_PREFIX . "photo_albums as pa" .
-                    " ON pa.photo_id = p.photo_id JOIN " .
-                    DB_PREFIX . "album_permissions as ap" .
-                    " ON pa.album_id = ap.album_id JOIN " .
-                    DB_PREFIX . "photo_people as pp" .
-                    " ON pp.photo_id = p.photo_id " .
-                    " WHERE pp.person_id = " . 
+                    DB_PREFIX . "photos AS p JOIN " .
+                    DB_PREFIX . "photo_albums AS pa " .
+                    "ON pa.photo_id = p.photo_id JOIN " .
+                    DB_PREFIX . "group_permissions AS gp " .
+                    "ON pa.album_id = gp.album_id JOIN " .
+                    DB_PREFIX . "groups_users AS gu " .
+                    "ON gp.group_id = gu.group_id JOIN " .
+                    DB_PREFIX . "photo_people AS pp " .
+                    "ON pp.photo_id = p.photo_id " .
+                    "WHERE pp.person_id = " . 
                     escape_string($this->get("person_id")) .
-                    " AND ap.user_id =" .
+                    " AND gu.user_id =" .
                     " '" . escape_string($user->get("user_id")) . "'" .
-                    " and ap.access_level >= p.level " .
+                    " AND gp.access_level >= p.level " .
                     $order;
             } else {
                 $sql =
@@ -193,38 +195,82 @@ class person extends zoph_table {
 }
 
 function get_people($constraints = null, $conj = "and", $ops = null,
-    $order = "last_name, first_name") {
-
+    $order = "last_name, first_name", $user=null) {
     return get_records("person", $order, $constraints, $conj, $ops);
 }
 
-function get_photographed_people($user = null, $first_letter=null) {
-    if($first_letter!==null) {
-        if($first_letter==="") {
-            $where=" and (ppl.last_name='' or ppl.last_name is null)";
-        } else {
-            $first_letter=escape_string($first_letter);
-            $where=" and ppl.last_name like lower('" . $first_letter . "%')";
+function get_people_count($user = null, $search = null) {
+    if($user && !$user->is_admin()) {
+        $allowed=array();
+        $people=get_photographed_people($user, $search);
+        $photographers=get_photographers($user, $search);
+        foreach($people as $person) {
+            $allowed[]=$person->get("person_id");
         }
+        foreach($photographers as $photographer) {
+            $allowed[]=$person->get("person_id");
+        }
+
+        $allowed=array_unique($allowed);
+
+        return count($allowed);
+    } else {
+        return get_count("person");
     }
+}
+
+function get_all_people($user = null, $search = null, $search_first = false) {
+    $allowed=array();
+
+    if($user && !$user->is_admin()) {
+        $people=get_photographed_people($user, $search, $search_first);
+        $photographers=get_photographers($user, $search, $search_first);
+        foreach($people as $person) {
+            $allowed[]=$person->get("person_id");
+        }
+        foreach($photographers as $photographer) {
+            $allowed[]=$person->get("person_id");
+        }
+
+        $allowed=array_unique($allowed);
+        if(count($allowed)==0) {
+            return null;
+        }
+        $keys=implode(",", $allowed);
+        $where=" WHERE person_id IN (" .$keys . ")";
+    } else if ($search!==null) {
+        $where=get_where_for_search(" WHERE ", $search, $search_first);
+    }
+
+    $sql="SELECT * FROM " . DB_PREFIX . "people AS ppl " . $where .
+        " ORDER BY last_name, called, first_name";
+
+    return get_records_from_query("person", $sql);
+}
+
+function get_photographed_people($user = null, $search=null, $search_first = false) {
+    $where=get_where_for_search(" and ", $search, $search_first);
     if ($user && !$user->is_admin()) {
-        $query =
+        $sql =
             "select distinct ppl.* from " .
-            DB_PREFIX . "people as ppl, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_people as pp, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "' " .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level" .
-            " and ph.photo_id = pp.photo_id " .
-            " and pp.person_id = ppl.person_id " . $where .
-            " order by ppl.last_name, ppl.called, ppl.first_name";
+            DB_PREFIX . "people AS ppl JOIN " .
+            DB_PREFIX . "photo_people AS pp " .
+            "ON ppl.person_id = pp.person_id JOIN " . 
+            DB_PREFIX . "photos AS ph " .
+            "ON ph.photo_id = pp.photo_id JOIN " .
+            DB_PREFIX . "photo_albums AS pa " .
+            "ON pa.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) . "' " .
+            " AND gp.access_level >= ph.level" . $where .
+            " ORDER BY ppl.last_name, ppl.called, ppl.first_name";
     }
     else {
-        $query =
+        $sql =
             "select distinct ppl.* from " .
             DB_PREFIX . "people as ppl, " .
             DB_PREFIX . "photo_people as pp " .
@@ -232,45 +278,66 @@ function get_photographed_people($user = null, $first_letter=null) {
             " order by ppl.last_name, ppl.called, ppl.first_name";
     }
 
-    return get_records_from_query("person", $query);
+    return get_records_from_query("person", $sql);
 }
 
-function get_photographers($user = null) {
-
+function get_photographers($user = null, $search = null, $search_first = null) {
+    $where=get_where_for_search(" and ", $search, $search_first);
     if ($user && !$user->is_admin()) {
-        $query =
+        $sql =
             "select distinct ppl.* from " .
-            DB_PREFIX . "people as ppl, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "' " .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level" .
-            " and ph.photographer_id = ppl.person_id " .
-            "order by ppl.last_name, ppl.called, ppl.first_name";
+            DB_PREFIX . "people as ppl " .
+            "WHERE person_id in " .
+            "(SELECT photographer_id FROM " .
+            DB_PREFIX . "photos as ph JOIN " .
+            DB_PREFIX . "photo_albums as pa " .
+            "ON pa.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "group_permissions AS gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) . "' " .
+            $where .
+            " AND gp.access_level >= ph.level)" .
+            " ORDER BY ppl.last_name, ppl.called, ppl.first_name";
     }
     else {
-        $query =
+        $sql =
             "select distinct ppl.* from " .
             DB_PREFIX . "people as ppl, " .
             DB_PREFIX . "photos as ph " .
-            "where ppl.person_id = ph.photographer_id " .
+            "where ppl.person_id = ph.photographer_id " . $where . 
             "order by ppl.last_name, ppl.called, ppl.first_name";
     }
 
-    return get_records_from_query("person", $query);
+    return get_records_from_query("person", $sql);
 }
 
-function get_people_select_array($people_array = null) {
+function get_where_for_search($conj, $search, $search_first) {
+    if($search!==null) {
+        if($search==="") {
+            $where=$conj . " (ppl.last_name='' or ppl.last_name is null)";
+        } else {
+            $search=escape_string($search);
+            $where=$conj . " (ppl.last_name like lower('" . $search . "%')";
+            if ($search_first) {
+                $where.="or ppl.first_name like lower('" . $search . "%'))";
+            } else {
+                $where.=")";
+            }
+        }
+    }
+    return $where;
+}
+
+function get_people_select_array($people_array = null, $user = null) {
 
     $ppl[""] = "";
 
     if (!$people_array) {
-        $people_array = get_people();
+        $people_array = get_people(null,null,null,null,$user);
     }
-
     if ($people_array) {
         foreach ($people_array as $person) {
             $ppl[$person->get("person_id")] =
@@ -319,9 +386,9 @@ function get_person_by_name($first_name = null, $last_name = null) {
     }
     $where .= $last_name;
 
-    $query = "select person_id from " . DB_PREFIX . "people where $where";
+    $sql = "select person_id from " . DB_PREFIX . "people where $where";
 
-    return get_records_from_query("person", $query);
+    return get_records_from_query("person", $sql);
 }
 
 function get_popular_people($user) {
@@ -330,21 +397,24 @@ function get_popular_people($user) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select ppl.*, count(distinct ph.photo_id) as count from " .
-            DB_PREFIX . "people as ppl, " .
-            DB_PREFIX . "photo_people as pp, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "' " .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = pp.photo_id" .
-            " and pp.person_id = ppl.person_id" .
-            " and pp.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level " .
-            "group by ppl.person_id " .
-            "order by count desc, ppl.last_name, ppl.first_name " .
-            "limit 0, " . escape_string($TOP_N);
+            "SELECT ppl.*, COUNT(DISTINCT ph.photo_id) AS count FROM " .
+            DB_PREFIX . "people as ppl JOIN " .
+            DB_PREFIX . "photo_people as pp " .
+            "ON pp.person_id = ppl.person_id JOIN " .
+            DB_PREFIX . "photos as ph " .
+            "ON pp.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "photo_albums as pa " .
+            "ON pa.photo_id = pp.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) . "' " .
+            " AND gp.access_level >= ph.level " .
+            "GROUP BY ppl.person_id " .
+            "ORDER BY count DESC, ppl.last_name, ppl.first_name " .
+            "LIMIT 0, " . escape_string($TOP_N);
     }
     else {
         $sql =
@@ -361,4 +431,40 @@ function get_popular_people($user) {
 
 }
 
+function create_person_pulldown($name, $value=null, $user) {
+    $id=ereg_replace("^_+", "", $name);
+    if($value) {
+        $person=new person($value);
+        $person->lookup();
+        $text=$person->get_name();
+    }
+    if($user->prefs->get("autocomp_people") && AUTOCOMPLETE && JAVASCRIPT) {
+        $html="<input type=hidden id='" . $id . "' name='" . $name. "'" .
+            " value='" . $value . "'>";
+        $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
+            " value='" . $text . "' class='autocomplete'>";
+    } else {
+        $html=create_pulldown($name, $value, get_people_select_array(null,$user));
+    }
+    return $html;
+}
+
+function create_photographer_pulldown($name, $value=null, $user) {
+    $id=ereg_replace("^_+", "", $name);
+    if($value) {
+        $person=new person($value);
+        $person->lookup();
+        $text=$person->get_name();
+    }
+    if($user->prefs->get("autocomp_photographer") && AUTOCOMPLETE && JAVASCRIPT) {
+        $html="<input type=hidden id='" . $id . "' name='" . $name. "'" .
+            " value='" . $value . "'>";
+        $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
+            " value='" . $text . "' class='autocomplete'>";
+    } else {
+        $html=create_pulldown($name, $value, get_photographer_search_array($user));
+    }
+    return $html;
+}
+
 ?>
