@@ -37,15 +37,17 @@ class photo extends zoph_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select p.* from " .
-                DB_PREFIX . "photos as p, " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where p.photo_id = '" . escape_string($this->get("photo_id")) . "'" .
-                " and p.photo_id = pa.photo_id" .
-                " and pa.album_id = ap.album_id" .
-                " and ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-                " and ap.access_level >= p.level " .
-                "limit 0, 1";
+                DB_PREFIX . "photos as p JOIN " .
+                DB_PREFIX . "photo_albums as pa " .
+                "ON p.photo_id = pa.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE p.photo_id = '" . escape_string($this->get("photo_id")) . "'" .
+                " AND gu.user_id = '" . escape_string($user->get("user_id")) . "'" .
+                " AND gp.access_level >= p.level " .
+                "LIMIT 0, 1";
         }
         else {
             $sql =
@@ -136,10 +138,10 @@ class photo extends zoph_table {
             $album_permissions=$user->get_album_permissions($album_id);
 
             if($user->is_admin() || $album_permissions->get("writable")) {
-                execute_query($sql, 1);
+                query($sql);
             }
         } else {
-            execute_query($sql, 1);
+            query($sql);
         }
     }
 
@@ -153,7 +155,7 @@ class photo extends zoph_table {
                 "delete from " . DB_PREFIX . "photo_albums " .
                 "where photo_id = '" . escape_string($this->get("photo_id")) . "'" .
                 " and album_id = '" . escape_string($album_id) . "'";
-            execute_query($sql, 1);
+            query($sql);
         }
     }
 
@@ -163,7 +165,7 @@ class photo extends zoph_table {
             "(photo_id, category_id) values ('" .
             escape_string($this->get("photo_id")) . "', '" .
             escape_string($category_id) . "')";
-        execute_query($sql, 1);
+        query($sql);
     }
 
     function remove_from_category($category_ids) {
@@ -176,7 +178,7 @@ class photo extends zoph_table {
                 "delete from " . DB_PREFIX . "photo_categories " .
                 "where photo_id = '" . escape_string($this->get("photo_id")) . "'" .
                 " and category_id = '" . escape_string($category_id) . "'";
-            execute_query($sql, 1);
+            query($sql);
         }
     }
 
@@ -190,7 +192,7 @@ class photo extends zoph_table {
             "(photo_id, person_id, position) " .
             "values ('" . escape_string($this->get("photo_id")) . "', '" .
             escape_string($person_id) . "', $position)";
-        execute_query($sql);
+        query($sql, "Failed to add person");
     }
 
     function remove_from_person($person_ids) {
@@ -203,7 +205,7 @@ class photo extends zoph_table {
                 "delete from " . DB_PREFIX . "photo_people " .
                 "where photo_id = '" . escape_string($this->get("photo_id")) . "'" .
                 " and person_id = '" . escape_string($person_id) . "'";
-            execute_query($sql);
+            query($sql);
         }
     }
 
@@ -211,19 +213,21 @@ class photo extends zoph_table {
 
         if ($user && !$user->is_admin()) {
             $sql =
-                "select al.album_id, al.parent_album_id, al.album from " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "albums as al, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where pa.photo_id = '" .
+                "SELECT al.album_id, al.parent_album_id, al.album FROM " .
+                DB_PREFIX . "albums AS al JOIN " .
+                DB_PREFIX . "photo_albums AS pa " .
+                "ON al.album_id = pa.album_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE pa.photo_id = '" .
                 escape_string($this->get("photo_id")) . "'" .
-                " and pa.album_id = al.album_id" .
-                " and al.album_id = ap.album_id" .
-                " and ap.user_id = '" .
+                " AND gu.user_id = '" .
                 escape_string($user->get("user_id")) . "' " .
-                " and ap.access_level >= " .
-                escape_string($this->get("level")) . " " .
-                "order by al.album";
+                " AND gp.access_level >= " .
+                escape_string($this->get("level")) .
+                " ORDER BY al.album";
         }
         else {
             $sql =
@@ -362,22 +366,28 @@ class photo extends zoph_table {
 return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " alt=\"$alt\"" . ">";
 }
 
-    function get_rating($user_id) {
+    function get_rating($user) {
 
         $photo_id = $this->get("photo_id");
+        $user_id=$user->get("user_id");
+
+        if ($user->get("allow_multirating")) {
+            // This user is allowed to rate the same photoe  multiple 
+            // times, however we will allow only one from the same IP
+            $where = " and ipaddress = '" . 
+                escape_string($_SERVER["REMOTE_ADDR"])."' ";
+        }
 
         $query =
             "select rating from " . DB_PREFIX . "photo_ratings " .
             "where user_id = '" . escape_string($user_id) . "'" .
-            " and photo_id = '". escape_string($this->get("photo_id")) . "'";
+            " and photo_id = '". escape_string($this->get("photo_id")) . "'" .
+            $where;
 
-        if (DEBUG > 1) { echo "$query<br>\n"; }
-
-        $result = mysql_query($query)
-            or die_with_mysql_error("Rating lookup failed");
+        $result = query($query, "Rating lookup failed");
 
         $rating = null;
-        if ($row = mysql_fetch_array($result)) {
+        if ($row = fetch_array($result)) {
             $rating = $row[0];
         }
 
@@ -390,72 +400,96 @@ return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " al
      *
      * This function from Jan Miczaika
      */
-    function rate($user_id, $rating) {
+    function rate($user, $rating) {
 
-        if (!$user_id || !$rating) {
+        if (!$user || !$rating) {
             return null;
         }
+        $user_id=$user->get("user_id");
+        if(!($user->is_admin() || $user->get("allow_rating"))) {
+            return;
+        }
 
         $photo_id = $this->get("photo_id");
 
+        if ($user->get("allow_multirating")) {
+            // This user is allowed to rate the same photoe  multiple 
+            // times, however we will allow only one from the same IP
+            $where = " and ipaddress = '" . 
+                escape_string($_SERVER["REMOTE_ADDR"])."' ";
+        }
+
         $query =
             "select * from " . DB_PREFIX . "photo_ratings " .
             "where user_id = '" . escape_string($user_id) . "'" .
-            " and photo_id = '". escape_string($photo_id) . "'";
+            " and photo_id = '". escape_string($photo_id) . "'" .
+            $where;
 
-        if (DEBUG > 1) { echo "$query<br>\n"; }
-
-        $result = mysql_query($query)
-            or die_with_mysql_error("Rating lookup failed");
+        $result = query($query, "Rating lookup failed");
 
         //if the user has already voted, update the vote, else insert a new one
 
-        if (mysql_num_rows($result) > 0) {
+        if (num_rows($result) > 0) {
             $query =
                 "update " . DB_PREFIX . "photo_ratings " .
-                "set rating = '" . escape_string($rating) . "' " .
+                "set rating = '" . escape_string($rating) . "', " .
+                " ipaddress = '" . escape_string($_SERVER["REMOTE_ADDR"])."' " .
                 "where user_id = '" . escape_string($user_id) . "'" .
-                " and photo_id = '". escape_string($photo_id) . "'";
+                " and photo_id = '". escape_string($photo_id) . "'" .
+                $where . " LIMIT 1";
+                // The limit makes sure only 1 vote is updated, this is 
+                // needed if you ever change the allow_multirating to
+                // 'no' and there already have been multiple votes
+                // by this user. It will, however, simply update the first
+                // vote it encounters...
         }
         else {
             $query =
                 "insert into " . DB_PREFIX . "photo_ratings " .
-                "(photo_id, user_id, rating) values " .
+                "(photo_id, user_id, ipaddress, rating) values " .
                 " ('" . escape_string($photo_id) . "', '" .
                 escape_string($user_id) . "', '" .
+                escape_string($_SERVER["REMOTE_ADDR"])."', '" .
                 escape_string($rating) . "')";
         }
 
-        if (DEBUG > 1) { echo "$query<br>\n"; }
-
-        $result = mysql_query($query)
-            or die_with_mysql_error("Rating input failed");
+        $result = query($query, "Rating input failed");
 
         //now recalculate the average, and input it in the photo table
+        $this->recalculate_rating();
+    }
 
+    function recalculate_rating() {
+        $photo_id = $this->get("photo_id");
         $query = "select avg(rating) from " . DB_PREFIX . "photo_ratings ".
             " where photo_id = '" . escape_string($photo_id) . "'";
 
-        if (DEBUG > 1) { echo "$query<br>\n"; }
 
-        $result = mysql_query($query)
-            or die_with_mysql_error("Rating recalculation failed");
+        $result = query($query, "Rating recalculation failed");
 
-        $row = mysql_fetch_array($result);
+        $row = fetch_array($result);
 
         $avg = (round(100 * $row[0])) / 100.0;
 
         $query = "update " . DB_PREFIX . "photos set rating = $avg" .
             " where photo_id = '" . escape_string($photo_id) . "'";
 
-        if (DEBUG > 1) { echo "$query<br>\n"; }
-
-        $result = mysql_query($query)
-            or die_with_mysql_error("Inserting new rating failed");
+        $result = query($query, "Inserting average rating failed");
 
         return $avg;
     }
 
+    function delete_rating($rating_id) {
+        if(!is_numeric($rating_id)) { 
+            die("<b>rating_id</b> must be numeric!"); 
+        }
+        $sql = "DELETE FROM " . DB_PREFIX . "photo_ratings WHERE " .
+            "rating_id = " . escape_string($rating_id);
+        query($sql);
+        $this->recalculate_rating();
+        return;
+    }
+
     function get_image_resource() {
         $file = $this->get_file_path();
         $img_src = null;
@@ -904,10 +938,8 @@ echo ("<br>\noutString:<br>\n" . $out_string);
                 $this->get("date") . " " .
                 $this->get("time"),
                 $camera_tz);
-            $place_time=new Time(
-                $this->get("date") . " " .
-                $this->get("time"),
-                $place_tz);
+            $place_time=$camera_time;
+            $place_time->setTimezone($place_tz);
             $corr=$this->get("time_corr");
             if($corr) {
                 $place_time->modify($corr . " minutes");
@@ -975,7 +1007,45 @@ echo ("<br>\noutString:<br>\n" . $out_string);
         return $html;
     }
 
+    function get_rating_details($content, $open=false) {
+        $sql="SELECT rating_id, user_id, rating, ipaddress, timestamp FROM " .
+            DB_PREFIX . "photo_ratings WHERE photo_id=" .
+            escape_string($this->get("photo_id"));
 
+        $result=query($sql);
+        
+        $html="&nbsp;";
+        if ($open) {
+            $html.="<span onclick=\"unbranch(this)\">-&nbsp;</span>";
+        } else {
+            $html.="<span onclick=\"branch(this)\">+&nbsp;</span>";
+        }
+        $html.="<span class='showhide'>" . $content . "</span>";
+        $html.="<div class='ratingdetail'>\n";
+        $html.="<table class='ratingdetail'>\n<tr>\n";
+        $html.="<th>" . translate("user") . "</th>";
+        $html.="<th>" . translate("rating") . "</th>";
+        $html.="<th>" . translate("IP address") . "</th>";
+        $html.="<th>" . translate("date") . "</th></tr>";
+
+        while($row=fetch_row($result)) {
+            $html.="<tr>\n";
+            $this_user=new user($row[1]);
+            $this_user->lookup();
+            $html.="<td>" . $this_user->get_link() . "</td>\n" .
+                "<td>" . $row[2] . "</td>\n" .
+                "<td>" . $row[3] . "</td>\n" .
+                "<td>" . $row[4] . "</td>\n" .
+                "<td><span class='actionlink'>" .
+                "<a href='photo.php?_action=delrate" .
+                "&photo_id=" . $this->get("photo_id") .
+                "&_rating_id=" .  $row[0] . "'>" . 
+                translate("delete") . "</a></span></td>" .
+                "</tr>\n";
+        }
+        $html.="</table>\n</div>";
+        return $html;
+    }
     function get_comments() {
         $sql = "select comment_id from " . DB_PREFIX . "photo_comments where" .
             " photo_id = " .  $this->get("photo_id");
@@ -1010,9 +1080,8 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             " union select desc_2 from " . DB_PREFIX . "photo_relations where" .
             " photo_id_1 = " . escape_string($this->get("photo_id")) . " and " .
             " photo_id_2 = " . escape_string($photo_id_2) . " limit 1";
-        $result=mysql_query($sql)
-            or die("Could not get description for related photo:<br><i>$sql</i>");
-        $result=mysql_fetch_row($result);
+        $result=query($sql, "Could not get description for related photo:");
+        $result=fetch_row($result);
         return $result[0];
     }
     
@@ -1022,8 +1091,7 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             escape_string($photo_id_2) . "," .
             "\"" . escape_string($desc_1) . "\"," .
             "\"" . escape_string($desc_2) . "\")";
-        $result=mysql_query($sql)
-            or die_with_mysql_error("Could not create relation:<br><i>$sql</i>");
+        $result=query($sql, "Could not create relation");
         }
         
     function update_relation($photo_id_2, $desc_1 = null, $desc_2 = null) {
@@ -1034,17 +1102,15 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             " desc_2=\"" . escape_string($desc_2) . "\"" .
             " where photo_id_1=" . $photo_id_1 .
             " and photo_id_2=" . $photo_id_2;
-        mysql_query($sql)
-            or die_with_mysql_error("Could not update relation:<br><i>$sql</i>");
+        query($sql, "Could not update relation:");
         // A relation may be the other way around...
         $sql = "update " . DB_PREFIX . "photo_relations set" .
             " desc_2=\"" . escape_string($desc_1) . "\"," .
             " desc_1=\"" . escape_string($desc_2) . "\"" .
             " where photo_id_2=" . $photo_id_1 .
             " and photo_id_1=" . $photo_id_2;
-        mysql_query($sql)
-            or die_with_mysql_error("Could not update relation:<br><i>$sql</i>");
-        }
+        query($sql, "Could not update relation:");
+    }
     
     function delete_relation($photo_id_2) {
         $ids="(" . escape_string($this->get("photo_id")) . "," .
@@ -1052,8 +1118,7 @@ echo ("<br>\noutString:<br>\n" . $out_string);
         $sql = "delete from " . DB_PREFIX . "photo_relations" .
             " where photo_id_1 in " . $ids .
             " and photo_id_2 in " . $ids;
-        $result=mysql_query($sql)
-            or die_with_mysql_error("Could not delete relation:<br><i>$sql</i>");
+        $result=query($sql, "Could not delete relation:");
     }    
     
     function exif_to_html() {
@@ -1181,71 +1246,55 @@ function create_rating_graph($user) {
 
     if ($user && !$user->is_admin()) {
         $query =
-            "select round(ph.rating), count(distinct ph.photo_id) as count from " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level " .
-            "group by round(rating) order by round(rating)";
-    }
-    else {
+            "select floor(ph.rating+0.5), " . 
+            "count(distinct ph.photo_id) as count from " .
+            DB_PREFIX . "photos as ph JOIN " .
+            DB_PREFIX . "photo_albums as pa " .
+            "ON ph.photo_id = pa.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) .
+            "' AND gp.access_level >= ph.level " .
+            "GROUP BY floor(rating+0.5) ORDER BY floor(rating+0.5)";
+    } else {
         $query =
-            "select round(rating), count(*) from " . DB_PREFIX . "photos " .
-            "group by round(rating) order by round(rating)";
+            "select floor(rating+0.5), count(*) from " . DB_PREFIX . "photos " .
+            "group by floor(rating+0.5) order by floor(rating+0.5)";
     }
 
-    if (DEBUG) { echo "$query<br>\n"; }
+    $result = query($query, "Rating grouping failed");
 
-    $result = mysql_query($query)
-        or die_with_mysql_error("Rating grouping failed");
-
-    $max_count = 0;
-    while ($row = mysql_fetch_array($result)) {
-        $max_count = max($max_count, $row[1]);	
+    while ($row = fetch_array($result)) {
     	$ratings[($row[0] ? $row[0] : translate("Not rated"))]=$row[1];
 	}
-?>
-    <h3><?php echo translate("photo ratings") ?></h3>
-<?php
-    if ($max_count) { 
-    $table =
-        "<table class=\"ratings\">\n<tr>\n" .
-        "<th>" . translate("rating") . "</th>\n" .
-        "<th>" . translate("count") . "</th>\n  </tr>\n";
-
-    $scale = 150.0 / $max_count;
-	
+    $html="<h3>" . translate("photo ratings") . "</h3>";
+    $legend=array(translate("rating"),translate("count"));
     while (list($range, $count) = each($ratings)) {
         if($range>0) {
-	   $min_rating=$range-0.5;
-	   $max_rating=$range+0.5;
-           $qs =
-              "search.php?rating%5B0%5D=" . $min_rating . "&amp;_rating_op%5B0%5D=%3E%3D" .
-              "&amp;rating%5B1%5D=" . $max_rating . "&amp;_rating_op%5B1%5D=%3C&amp;_action=" . translate("search");
+            $min_rating=$range-0.5;
+	        $max_rating=$range+0.5;
+            $link =
+              "search.php?rating%5B0%5D=" . $min_rating . 
+              "&amp;_rating_op%5B0%5D=%3E%3D" .
+              "&amp;rating%5B1%5D=" . $max_rating . 
+              "&amp;_rating_op%5B1%5D=%3C&amp;_action=" . translate("search");
         } else {
-           $qs = "photos.php?rating=null";
+            $link = "photos.php?rating=null";
         }  
-        $table .=
-            "  <tr>\n    <td>\n" .
-            "      <a href=\"$qs\">$range</a></td>\n" .
-            "      <td>\n";
-
-	$table .= "<div class=\"ratings\" style=\"width: " . ceil($scale * $count) . "px;\">&nbsp;</div>";
-        $table .= "[$count]\n    </td>\n  </tr>\n";
+        $row=array($range, $link, $count);
+        $value_array[]=$row;
     }
 
-    $table .="</table>\n";
-
-    }
-    else {
-        $table .=
-            translate("No photo was found.") . "\n";
+    if($value_array) {
+        $html.=create_bar_graph($legend, $value_array, 150);
+    } else {
+        $html.=translate("No photo was found.") . "\n";
     }
 
-    return $table;
+    return $html;
 }
 
 /*
@@ -1309,4 +1358,5 @@ function ImageStringWrap($image, $font, $x, $y, $text, $color, $maxwidth) {
         $y += $fontheight;
     }
 }
+
 ?>
