@@ -43,23 +43,52 @@ class place extends zoph_tree_table {
 
         $sql="update " . DB_PREFIX . "photos set location_id=null where " .
             "location_id=" . $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
 
         $sql="update " . DB_PREFIX . "people set home_id=null where " .
             "home_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:", $sql);
 
         $sql="update " . DB_PREFIX . "people set work_id=null where " .
             "work_id=" .  $id;
-        if (DEBUG) { echo "$sql<br>\n"; }
-        mysql_query($sql) or die_with_mysql_error("Could not remove references:", $sql);
+        query($sql, "Could not remove references:");
         
         parent::delete();
     }
 
+    function get_children($user=null,$order=null) {
+        if($order=="sortname") {
+            #places do not have a sortname
+            $order="name";
+        }
+        if($order && $order!="name") {
+            $order_fields=get_sql_for_order($order);
+            $order=" ORDER BY " . $order . ", name ";
+        } else if ($order=="name") {
+            $order=" ORDER BY name ";
+        }
+        
+        $id = $this->get("place_id");
+        if (!$id) { return; }
 
+        $sql =
+            "SELECT pl.*, pl.title as name " .
+            $order_fields . " FROM " .
+            DB_PREFIX . "places as pl LEFT JOIN " .
+            DB_PREFIX . "photos as ph " .
+            "ON pl.place_id = ph.location_id " .
+            "WHERE pl.parent_place_id=" . escape_string($id) .
+            " GROUP BY pl.place_id " .
+            $order; 
+
+        $this->children=get_records_from_query("place", $sql);
+        if($user) {
+            return remove_empty($this->children, $user);
+        } else {
+            return $this->children; 
+        }
+    }    
+    
     function tzid_to_timezone() {
         $tzkey=$this->get("timezone_id");
         if($tzkey>0) {
@@ -142,14 +171,16 @@ class place extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(*) from " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where p.location_id = $id" .
-                " and ap.user_id = '" . escape_string($user->get("user_id")) .
-                "' and ap.album_id = pa.album_id" .
-                " and pa.photo_id = p.photo_id " .
-                " and ap.access_level >= p.level";
+                DB_PREFIX . "photos as p JOIN " .
+                DB_PREFIX . "photo_albums as pa " .
+                "ON p.photo_id = pa.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE p.location_id = " . escape_string($id) .
+                " AND gu.user_id = '" . escape_string($user->get("user_id")) .
+                "' AND gp.access_level >= p.level";
 }
         else {
             $sql =
@@ -173,16 +204,18 @@ class place extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(distinct pa.photo_id) from " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
-                DB_PREFIX . "album_permissions as ap " .
-                "where ap.user_id = '" . escape_string($user->get("user_id")) .
-                "' and ap.album_id = pa.album_id " .
-                " and pa.photo_id = p.photo_id " .
-                " and ap.access_level >= p.level";
+                DB_PREFIX . "photos as p JOIN " .
+                DB_PREFIX . "photo_albums as pa " .
+                "ON pa.photo_id = p.photo_id JOIN " .
+                DB_PREFIX . "group_permissions as gp " .
+                "ON pa.album_id = gp.album_id JOIN " .
+                DB_PREFIX . "groups_users as gu " .
+                "ON gp.group_id = gu.group_id " .
+                "WHERE gu.user_id = '" . escape_string($user->get("user_id")) .
+                "' AND gp.access_level >= p.level";
 
             if ($id_constraint) {
-                $sql .= " and $id_constraint";
+                $sql .= " AND $id_constraint";
             }
         }
         else {
@@ -227,12 +260,14 @@ class place extends zoph_tree_table {
                     DB_PREFIX . "photos as p JOIN " .
                     DB_PREFIX . "photo_albums as pa" .
                     " ON pa.photo_id = p.photo_id JOIN " .
-                    DB_PREFIX . "album_permissions as ap " .
-                    " ON pa.album_id = ap.album_id " .
+                    DB_PREFIX . "group_permissions as gp " .
+                    "ON pa.album_id = gp.album_id JOIN " .
+                    DB_PREFIX . "groups_users as gu " .
+                    "ON gp.group_id = gu.group_id " .
                     $place_where .
-                    " AND ap.user_id =" .
+                    " AND gu.user_id =" .
                     " '" . escape_string($user->get("user_id")) . "'" .
-                    " and ap.access_level >= p.level " .
+                    " and gp.access_level >= p.level " .
                     $order;
             } else {
                 $sql =
@@ -256,7 +291,7 @@ class place extends zoph_tree_table {
     function get_mapping_js($user,$edit=false) {
          $js=parent::get_mapping_js($user, ICONSET . "/geo-place.png", $edit);
          if (!$edit) {
-            $js.=get_markers($this->get_children(), $user);
+            $js.=get_markers($this->get_children($user), $user);
         }
         return $js;
     }
@@ -302,19 +337,23 @@ class place extends zoph_tree_table {
         $timezone=$this->get("timezone");
         if(!$timezone && $lat && $lon) {
             $tz=guess_tz($lat, $lon);
-            $html="<span class='actionlink'>" .
-                "<a href=place.php?_action=update&place_id=" .
-                $this->get("place_id") . "&timezone=" . $tz .
-                ">" . $tz . "</a></span>";
+            if($tz) {
+                $html="<span class='actionlink'>" .
+                    "<a href=place.php?_action=update&place_id=" .
+                    $this->get("place_id") . "&timezone=" . $tz .
+                    ">" . $tz . "</a></span>";
+            }
             return $html;
         }
         return null;
     }
 
     function set_tz_children($tz) {
-        $places=$this->get_children();
+        $places;
+        $places=$this->get_branch_id_array($places);
         if($places) {
-            foreach ($places as $place) {
+            foreach ($places as $place_id) {
+                $place=new place($place_id);
                 $place->set("timezone", $tz);
                 $place->update();
             }
@@ -327,24 +366,6 @@ function get_places($constraints = null, $conj = "and", $ops = null,
     return get_records("place", $order, $constraints, $conj, $ops);
 }
 
-/* function get_children() {
-// This function looks so broken, I can only assume it was never used.
-    $id = $this->get("album_id");
-    if (!$id) { return; }
-
-   $sql =
-         "select place_id, title, address, address2, city, ".
-         "state, zip, country, notes from " .
-         DB_PREFIX . "places" .
-         "where p.parent_place_id = '" . escape_string($id) . "'" .
-         " order by p.title";
-
-    $this->children = get_records_from_query("album", $sql);
-
-    return $this->children;
-
-} */
-
 function get_root_place() {
     return new place(1);
 }
@@ -352,21 +373,24 @@ function get_root_place() {
 function get_photographed_places($user = null) {
 
     if ($user && !$user->is_admin()) {
-        $query =
-            "select distinct plc.* from " .
-            DB_PREFIX . "places as plc, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "' " .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ap.access_level >= ph.level" .
-            " and ph.location_id = plc.place_id " .
-            "order by plc.city, plc.title";
+        $sql =
+            "SELECT DISTINCT plc.* FROM " .
+            DB_PREFIX . "photos AS ph JOIN " .
+            DB_PREFIX . "places AS plc " .
+            "ON ph.location_id = plc.place_id JOIN " .
+            DB_PREFIX . "photo_albums AS pa " .
+            "ON pa.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "group_permissions AS gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users AS gu " .
+            "ON gp.group_id = gu.group_id " .
+            "where gu.user_id = '" . 
+            escape_string($user->get("user_id")) .
+            "' AND gp.access_level >= ph.level " .
+            "ORDER BY plc.city, plc.title";
     }
     else {
-        $query =
+        $sql =
             "select distinct plc.* from " .
             DB_PREFIX . "places as plc, " .
             DB_PREFIX . "photos as ph " .
@@ -374,7 +398,16 @@ function get_photographed_places($user = null) {
             "order by plc.city, plc.title";
     }
 
-    return get_records_from_query("place", $query);
+    return get_records_from_query("place", $sql);
+}
+
+function get_places_count($user) {
+    if($user && !$user->is_admin()) {
+        $places=get_photographed_places($user);
+        return count($places);
+    } else {
+        return get_count("category");
+    }
 }
 
 function get_places_select_array($user = null, $search = 0) {
@@ -391,19 +424,22 @@ function get_popular_places($user) {
 
     if ($user && !$user->is_admin()) {
         $sql =
-            "select plc.*, count(distinct ph.photo_id) as count from " .
-            DB_PREFIX . "places as plc, " .
-            DB_PREFIX . "photos as ph, " .
-            DB_PREFIX . "photo_albums as pa, " .
-            DB_PREFIX . "album_permissions as ap " .
-            "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-            " and ap.album_id = pa.album_id" .
-            " and pa.photo_id = ph.photo_id" .
-            " and ph.location_id = plc.place_id" .
-            " and ap.access_level >= ph.level " .
-            "group by plc.place_id " .
-            "order by count desc, plc.title, plc.city " .
-            "limit 0, $TOP_N";
+            "SELECT plc.*, count(distinct ph.photo_id) AS count FROM " .
+            DB_PREFIX . "photos as ph JOIN " .
+            DB_PREFIX . "places as plc " .
+            "ON ph.location_id = plc.place_id JOIN " .
+            DB_PREFIX . "photo_albums as pa " .
+            "ON pa.photo_id = ph.photo_id JOIN " .
+            DB_PREFIX . "group_permissions as gp " .
+            "ON pa.album_id = gp.album_id JOIN " .
+            DB_PREFIX . "groups_users as gu " .
+            "ON gp.group_id = gu.group_id " .
+            "WHERE gu.user_id = '" . 
+            escape_string($user->get("user_id")) . 
+            "' AND gp.access_level >= ph.level " .
+            "GROUP BY plc.place_id " .
+            "ORDER BY count desc, plc.title, plc.city " .
+            "LIMIT 0, $TOP_N";
     }
     else {
         $sql =
@@ -420,6 +456,24 @@ function get_popular_places($user) {
 
 }
 
+function create_place_pulldown($name, $value=null, $user=null) {
+    $id=ereg_replace("^_+", "", $name);
+    if($value) {
+        $place=new place($value);
+        $place->lookup();
+        $text=$place->get("title");
+    }
+    if($user->prefs->get("autocomp_places") && AUTOCOMPLETE && JAVASCRIPT) {
+        $html="<input type=hidden id='" . $id . "' name='" . $name. "'" .
+            " value='" . $value . "'>";
+        $html.="<input type=text id='_" . $id . "' name='_" . $name. "'" .
+            " value='" . $text . "' class='autocomplete'>";
+    } else {
+        $html=create_pulldown($name, $value, get_places_search_array($user));
+    }
+    return $html;
+}
+
 function create_zoom_pulldown($val = "", $name = "mapzoom") {
     $zoom_array = array(
         "0" => translate("0 - world", 0),
