@@ -83,58 +83,6 @@ function create_pulldown($name, $value, $value_array, $extraopt = null) {
     return $html;
 }
 
-function create_grouped_pulldown($name, $value, $value_array) {
-    $id=ereg_replace("^_+", "", $name);
-    $html = "<select name=\"$name\" id=\"$id\">\n";
-
-    $current_label = "";
-    $optgroup;
-    while (list($val, $label) = each($value_array)) {
-        list($left, $right) = explode(', ', $label);
-
-        if (!$right && $left) {
-            $right = $left;
-            $left = "[]";
-            $label = "$left, $right";
-        }
-
-        if ($left != $current_label) {
-            $current_label = $left;
-            if ($optgroup) {
-                $html .= "  </optgroup>\n";
-            }
-            $html .= "  <optgroup label=\"$current_label\">\n";
-            $optgroup = 1;
-        }
-
-        if ($val == $value) { $selected = " selected"; }
-        else { $selected  = ""; }
-        $html .= "  <option label=\"$right\" value=\"$val\"$selected>$label</option>\n";
-    }
-
-    if ($optgroup) {
-        $html .= "  </optgroup>\n";
-    }
-
-    $html .= "</select>\n";
-    return $html;
-}
-
-function create_smart_pulldown($name, $value, $value_array, $extraopt = null) {
-
-    $size = sizeof($value_array);
-
-    if ($size <= GROUPED_PULLDOWN_SIZE) {
-        return create_pulldown($name, $value, $value_array, $extraopt);
-    }
-    else if ($size <= MAX_PULLDOWN_SIZE) {
-        return create_grouped_pulldown($name, $value, $value_array);
-    }
-    else {
-        return create_text_input($name, $value, 10, 10);
-    }
-}
-
 function create_integer_pulldown($name, $value, $min, $max) {
     for ($i = $min; $i <= $max; $i++) {
         $integer_array["$i"] = $i;
@@ -843,4 +791,108 @@ function create_map_js($provider=MAPS, $map="map") {
         "</script>";
     return $js;
 }
+
+function check_js($user) {
+    if (($user->prefs->get("autocomp_albums")) || 
+        ($user->prefs->get("autocomp_categories")) || 
+        ($user->prefs->get("autocomp_places")) || 
+        ($user->prefs->get("autocomp_people")) ||  
+        ($user->prefs->get("autocomp_photographer")) 
+        && AUTOCOMPLETE && JAVASCRIPT) {
+        
+        return "<noscript><div class='warning'><img class='icon' src='images/icons/" . ICONSET . "/" . "warning.png'>" . translate("You have enabled autocompletion for one or more dropdown boxes on this page, however, you do not seem to have Javascript support. You should either enable javascript or turn autocompletion off, or this page will not work as expected!") . "</div></noscript>";
+    }
+}
+
+function remove_empty($children, $user) {
+    $clean=array();
+    // If user is not admin, remove any children that do not have photos
+    if($user && !$user->is_admin()) {
+        foreach($children as $child) {
+            $count=$child->get_total_photo_count($user);
+            if($count>0) {
+                $clean[]=$child;
+            }
+        }
+        return $clean;
+    } else {
+        return $children;
+    } 
+}
+
+function get_sql_for_order($order) {
+    switch ($order) {
+    case "oldest":
+        $sql="min(ph.date) as oldest ";
+        break;
+    case "newest":
+        $sql="max(ph.date) as newest "; 
+        break;
+    case "first":
+        $sql="min(ph.timestamp) as first ";
+        break;
+    case "last":
+        $sql="max(ph.timestamp) as last ";
+        break;
+    case "lowest":
+        $sql="min(rating) as lowest "; 
+        break;
+    case "highest":
+        $sql="max(rating) as highest ";
+        break;
+    case "average":
+        $sql="avg(rating) as average ";
+        break;
+    case "random":
+        $sql="rand() as random ";
+        break;
+    }
+    if($sql) {
+        return ", " . $sql;
+    } else {
+        return null;
+    }
+}
+
+function create_bar_graph($legend, $value_array, $scale) {
+    # $value_array is an array that contains an array for each line 
+    # of the graph. Each of those arrays contains 3 values: 
+    # value: The value we're graphing, 
+    # link:  Where should it link to. (may be null)
+    # count: Count of that value;
+
+    foreach($value_array as $row) {
+        $counts[]=$row[2];
+    }
+    $max=max($counts);
+    $pixels=$scale/$max;
+
+    $html="<table class='ratings'>\n";
+    $html.="  <tr>\n";
+    $html.="    <th>" . $legend[0] ."</th>\n";
+    $html.="    <th>" . $legend[1] ."</th>\n";
+    $html.="  <tr>\n";
+
+    foreach($value_array as $row) {
+        $html.="  <tr>\n";
+        $html.="    <td>\n";
+        if($row[1]) {
+            $html.="   <a href='" . $row[1] . "'>";
+        }
+        $html.=$row[0];
+        if($row[1]) {
+            $html.="</a>\n";
+        }
+        $html.="    </td>\n";
+        $html.="    <td>\n";
+        $html.="      <div class='ratings' style='width: " . 
+            ceil($row[2]*$pixels) . "px'>";
+        $html.="&nbsp;</div>&nbsp;";
+        $html.=$row[2];
+        $html.="    </td>\n";
+        $html.="  </tr>\n";
+    }
+    $html.="</table>";
+    return $html;
+}
 ?>
