@@ -41,7 +41,7 @@
     $album_count = get_album_count($user);
     $album_photo_count = $album->get_total_photo_count($user);
     $category = get_root_category();
-    $category_count = get_count("category");
+    $category_count = get_category_count($user);
     $category_photo_count = $category->get_total_photo_count($user);
     echo "\n";
 ?>
@@ -54,13 +54,13 @@
                 <li><?php echo sprintf(translate("%s photos in %s"), $category_photo_count, $category_count) ?> <a href="categories.php"><?php echo $category_count == 1 ? translate("category") : translate("categories") ?></a></li>
 <?php
     if ($user->is_admin() || $user->get("browse_people")) {
-        $person_count = get_count("person");
+        $person_count = get_people_count($user);
 ?>
                 <li><?php echo $person_count ?> <a href="people.php"><?php echo $person_count == 1 ? translate("person", 0) : translate("people", 0) ?></a></li>
 <?php
     }
     if ($user->is_admin() || $user->get("browse_places")) {
-        $place_count = get_count("place");
+        $place_count = get_places_count($user);
 ?>
                 <li><?php echo $place_count ?> <a href="places.php"><?php echo $place_count == 1 ? translate("place", 0) : translate("places", 0) ?></a></li>
 <?php
