@@ -137,13 +137,9 @@ class zoph_table {
             $sql = "select * from $this->table_name where $constraint";
         }
 
-        if (DEBUG) { echo "$sql<br>\n"; }
-
-        $result = mysql_query($sql)
-            or die_with_mysql_error("Lookup failed:", $sql);
-
-        if (mysql_num_rows($result) == 1) {
-            $row = mysql_fetch_assoc($result);
+        $result = query($sql, "Lookup failed:");
+        if (num_rows($result) == 1) {
+            $row = fetch_assoc($result);
 
             $this->fields = array();
 
@@ -160,7 +156,7 @@ class zoph_table {
     /*
      * Inserts a record.  The default behavior is to ignore the
      * primary key field(s) with the assumption that these will
-     * be generated by mysql (auto_increment).  Passing a non null
+     * be generated by the db (auto_increment).  Passing a non null
      * parameter causes these fields to be manually inserted.
      */
     function insert($keep_key = null) {
@@ -201,11 +197,9 @@ class zoph_table {
 
         $sql = "insert into $this->table_name ($names) values ($values)";
 
-        if (DEBUG) { echo "$sql<br>\n"; }
+        query($sql, "Insert failed:");
 
-        mysql_query($sql) or die_with_mysql_error("Insert failed:", $sql);
-
-        $id = mysql_insert_id();
+        $id = insert_id();
 
         if ($this->primary_keys && count($this->primary_keys) == 1) {
             $this->fields[$this->primary_keys[0]] = $id;
@@ -236,17 +230,13 @@ class zoph_table {
 
         $sql = "delete from $this->table_name where $constraints";
 
-        if (DEBUG) { echo "$sql<br>\n"; }
-
-        mysql_query($sql) or die_with_mysql_error("Delete failed:", $sql);
+        query($sql, "Delete failed:");
 
         if ($extra_tables) {
             foreach ($extra_tables as $table) {
                 $table = DB_PREFIX . $table;
                 $sql = "delete from $table where $constraints";
-                if (DEBUG) { echo "$sql<br>\n"; }
-                mysql_query($sql) or
-                    die_with_mysql_error("Delete from $table failed:", $sql);
+                query($sql, "Delete from $table failed:");
             }
         }
     }
@@ -292,9 +282,7 @@ class zoph_table {
 
         $sql = "update $this->table_name set $values where $constraints";
 
-        if (DEBUG) { echo "$sql<br>\n"; }
-
-        mysql_query($sql) or die_with_mysql_error("Update failed:", $sql);
+        query($sql, "Update failed:");
 
     }
 
@@ -410,8 +398,6 @@ function get_count($class) {
 
     $sql = "select count(*) from $table";
 
-    if (DEBUG > 1) { echo "$sql<br>\n"; }
-
     return get_count_from_query($sql);
 }
 
@@ -420,12 +406,8 @@ function get_count($class) {
  * Executes the given query and returns the result.
  */
 function get_count_from_query($sql) {
-    if (DEBUG > 1) { echo "$sql<br>\n"; }
-
-    $result = mysql_query($sql)
-        or die_with_mysql_error("Unable to get count", $sql);
-
-    return mysql_result($result, 0, 0);
+    $result = query($sql, "Unable to get count");
+    return result($result, 0, 0);
 }
 
 /*
@@ -480,13 +462,10 @@ function get_records($class, $order = null, $constraints = null,
  */
 function get_records_from_query($class, $sql, $min = 0, $num = 0) {
 
-    if (DEBUG > 1) { echo "$sql<br>\n"; }
-
-    $result = mysql_query($sql)
-        or die_with_mysql_error("Unable to get records", $sql);
+    $result = query($sql, "Unable to get records");
 
     if ($min) {
-        mysql_data_seek($result, $min);
+        data_seek($result, $min);
     }
 
     if ($num) {
@@ -497,7 +476,7 @@ function get_records_from_query($class, $sql, $min = 0, $num = 0) {
 
     $objs = array();
     if ($class != null) {
-        while ((!$limit || $num-- > 0) && $row = mysql_fetch_assoc($result)) {
+        while ((!$limit || $num-- > 0) && $row = fetch_assoc($result)) {
             $obj = new $class;
             $obj->set_fields($row);
             $objs[] = $obj;
@@ -505,12 +484,12 @@ function get_records_from_query($class, $sql, $min = 0, $num = 0) {
     }
     else {
         // use to grab ids, for example
-        while ((!$limit || $num-- > 0) && $row = mysql_fetch_row($result)) {
+        while ((!$limit || $num-- > 0) && $row = fetch_row($result)) {
             $objs[] = $row[0];
         }
     }
 
-    mysql_free_result($result);
+    free_result($result);
     return $objs;
 }
 
@@ -577,13 +556,17 @@ function create_link_list($records) {
     return $links;
 }
 
-function get_xml($class, $search) {
+function get_xml($class, $search,$user=null) {
     $search=strtolower($search);
-    if($class=="location") {
+    if($class=="location" || $class=="home" || $class=="work") {
         $class="place";
-    } else if($class=="photographer") {
+    } else if ($class=="photographer") {
         $class="person";
-    } 
+        $subclass="photographer";
+    } else if ($class=="father" || $class=="mother" || $class=="spouse") {
+        $class="person";
+    }
+
 
     if($class=="person") {
         $tree=false;
@@ -608,17 +591,21 @@ function get_xml($class, $search) {
         if ($tree) {
             $obj = get_root($class);
             $obj->lookup();
-            $tree=$obj->get_xml_tree($xml, $search);
+            $tree=$obj->get_xml_tree($xml, $search, $user);
             $rootnode->appendChild($tree);
         } else {
-            if($class="person") {
-                $constraints=array("lower(first_name)" => $search . "%", "lower(last_name)"=> $search . "%", "lower(concat(first_name, \" \", last_name))" => $search . "%");
-                $conj="or";
-                $order="last_name";
-                $ops=array("lower(first_name)" => "like", "lower(last_name)" => "like", "lower(concat(first_name, \" \", last_name))" => "like");
-            }
-            $records=get_records($class, $order, $constraints, $conj, $ops);
-
+            if($class=="person") {
+                if($search=="") {
+                    $search=null;
+                }
+                if($subclass=="photographer") {
+                    $records=get_photographers($user,$search,true);
+                } else {
+                    $records=get_photographed_people($user,$search,true);
+                }
+            } else {
+                $records=get_records($class, $order, $constraints, $conj, $ops);
+            } 
             foreach($records as $record) {
                 $newchild=$xml->createElement($nodename);
                 $key=$xml->createElement("key");
@@ -637,53 +624,6 @@ function get_xml($class, $search) {
     return $xml->saveXML();
 }
 
-////////// some utility functions //////////
-
-/*
- * Escapes various characters in the given string using the
- * mysql_escape_string function.
- */
-function escape_string($str) {
-
-    /*
-       Now every request var should be retrieved from the
-       getvar() function, which will strip the slashes.
-    if (ini_get("magic_quotes_gpc")) {
-        // unstrip quotes
-        $str = stripslashes($str);
-    }
-    */
-    $str=str_replace(array("<", ">", "\"", "(", ")"), array("&lt;", "&gt;", "&quot;", "&#40;", "&#41;"), $str);
-    return mysql_escape_string($str);
-
-}
-
-/*
- * Simply executes the given query.  If silence is passed, any errors
- * are ignored.
- */
-function execute_query($sql, $silent = 0) {
-    if (DEBUG > 1) { echo "$sql<br>\n"; }
-    if ($silent) {
-        mysql_query($sql);
-    }
-    else {
-        mysql_query($sql) or die_with_mysql_error("Something went wrong", $sql);
-    }
-}
-
-function die_with_mysql_error($msg, $sql = "") {
-    $msg =
-        "<p><strong>$msg</strong><br>\n" .
-        "<code>" . mysql_error() . "</code></p>\n";
-
-    if ($sql) {
-        $msg .= "<hr><p><code>$sql</code></p>\n";
-    }
-
-    die($msg);
-}
-
 function get_zoph_info_array() {
     $album= get_root_album();
     $category = get_root_category();
@@ -701,16 +641,4 @@ function get_zoph_info_array() {
     );
 }
 
-function get_field_lengths($table_name) {
-
-    $db_fields = mysql_list_fields(DB_NAME, $table_name);
-    $columns = mysql_num_fields($db_fields);
-    for ($i = 0; $i < $columns; $i++) {
-        $field_lengths[mysql_field_name($db_fields, $i)] =
-            mysql_field_len($db_fields, $i);
-    }
-
-    return $field_lengths;
-}
-
 ?>
