@@ -59,8 +59,6 @@ class zoph_tree_table extends zoph_table {
             $sql .= " order by $order";
         }
 
-        if (DEBUG) { echo "$sql<br>\n"; }
-
         $this->children = get_records_from_query(get_class($this), $sql);
         return $this->children;
 
@@ -98,7 +96,7 @@ class zoph_tree_table extends zoph_table {
         $key = $this->primary_keys[0];
         $id_array[] = $this->get($key);
 
-        $this->get_children($user);
+        $this->get_children();
         if ($this->children) {
             foreach($this->children as $c) {
                 $c->get_branch_id_array($id_array, $user);
@@ -118,9 +116,9 @@ class zoph_tree_table extends zoph_table {
         return implode(",", $id_array);
     }
 
-    function get_html_tree($open=true) {
+    function get_html_tree($user=null,$open=true) {
         $this->lookup();
-        $children=$this->get_children();
+        $children=$this->get_children($user);
 
         $html="\n<li>";
         if($children) {
@@ -137,7 +135,7 @@ class zoph_tree_table extends zoph_table {
             $html.= "<ul>";
         }
         foreach($children as $child) {
-            $html .= $child->get_html_tree(false);
+            $html .= $child->get_html_tree($user,false);
         }
         if($children) {
             $html .= "</ul>";
@@ -149,7 +147,7 @@ class zoph_tree_table extends zoph_table {
 
 
 
-    function get_xml_tree($xml, $search) {
+    function get_xml_tree($xml, $search, $user=null) {
         $rootname=$this->xml_rootname();
         $nodename=$this->xml_nodename();
         $idname=$this->primary_keys[0];
@@ -157,7 +155,6 @@ class zoph_tree_table extends zoph_table {
         $newchild=$xml->createElement($nodename);
 
         $title=$this->get_name();
-
         $titleshort=strtolower(substr($title, 0, strlen($search)));
         if($titleshort == strtolower($search)) {
             $key=$this->get($idname);
@@ -170,10 +167,12 @@ class zoph_tree_table extends zoph_table {
             $newchild->appendChild($newchildkey);
             $newchild->appendChild($newchildtitle);
        }
-        if($this->get_children()) {
+       $order = $user->prefs->get("child_sortorder");
+       $children=$this->get_children($user, $order);
+        if($children) {
             $childset=$xml->createElement($rootname);
-            foreach($this->get_children() as $child) {
-                $newnode=$child->get_xml_tree($xml, $search);
+            foreach($children as $child) {
+                $newnode=$child->get_xml_tree($xml, $search,$user);
                 if (isset($newnode)) {
                     $childset->appendChild($newnode);
                 }
@@ -191,31 +190,29 @@ function get_root($class) {
 
 function create_tree_select_array($name, $user = null, $rec = null,
     $level = "", $select_array = null, $search = 0) {
-
     if (!$rec) {
         $rec = get_root($name);
         $rec->lookup();
         $select_array[""] = "";
     }
-    if ($search) {
-        $key = $rec->get_branch_ids($user);
-    }
-    else {
-        $key = $rec->get($name . "_id");
-    }
-    /* The main descriptor field for location is not "place", but "title" */
+    $key = $rec->get($name . "_id");
     $descname=$name;
     if($descname=="place"){ $descname="title"; }
 
     $select_array[$key] = $level . $rec->get($descname);
-    $children = $rec->get_children($user, $descname);
+    if($user) {
+        $user->lookup_prefs();
+        $order = $user->prefs->get("child_sortorder");
+    } else {
+        $order="name";
+    }
+    $children = $rec->get_children($user, $order);
     if ($children) {
         foreach ($children as $child) {
             $select_array = create_tree_select_array($name, $user, $child,
                 "$level&nbsp;&nbsp;&nbsp;", $select_array, $search);
         }
     }
-
     return $select_array;
 }
 
